==> kdsoap-1.9.0-1-armv7h.pkg.tar.xz: usr/lib/cmake/KDSoap/KDSoapTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDSoap::kdsoap" for configuration "Debug"
set_property(TARGET KDSoap::kdsoap APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdsoap PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_DEBUG "Qt5::Core;Qt5::Network"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/lib/libkdsoap.so.1.9.0"
  IMPORTED_SONAME_DEBUG "libkdsoap.so.1.9.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdsoap )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdsoap "${_IMPORT_PREFIX}/lib/libkdsoap.so.1.9.0" )

# Import target "KDSoap::kdsoap-server" for configuration "Debug"
set_property(TARGET KDSoap::kdsoap-server APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdsoap-server PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_DEBUG "KDSoap::kdsoap;Qt5::Core;Qt5::Network"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/lib/libkdsoap-server.so.1.9.0"
  IMPORTED_SONAME_DEBUG "libkdsoap-server.so.1.9.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdsoap-server )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdsoap-server "${_IMPORT_PREFIX}/lib/libkdsoap-server.so.1.9.0" )

# Import target "KDSoap::kdwsdl2cpp" for configuration "Debug"
set_property(TARGET KDSoap::kdwsdl2cpp APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdwsdl2cpp PROPERTIES
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/bin/kdwsdl2cpp"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdwsdl2cpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdwsdl2cpp "${_IMPORT_PREFIX}/bin/kdwsdl2cpp" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdsoap-1.9.1-1-armv7h.pkg.tar.xz: usr/lib/cmake/KDSoap/KDSoapTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDSoap::kdsoap" for configuration "Debug"
set_property(TARGET KDSoap::kdsoap APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdsoap PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_DEBUG "Qt5::Core;Qt5::Network"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/lib/libkdsoap.so.1.9.1"
  IMPORTED_SONAME_DEBUG "libkdsoap.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdsoap )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdsoap "${_IMPORT_PREFIX}/lib/libkdsoap.so.1.9.1" )

# Import target "KDSoap::kdsoap-server" for configuration "Debug"
set_property(TARGET KDSoap::kdsoap-server APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdsoap-server PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_DEBUG "KDSoap::kdsoap;Qt5::Core;Qt5::Network"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/lib/libkdsoap-server.so.1.9.1"
  IMPORTED_SONAME_DEBUG "libkdsoap-server.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdsoap-server )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdsoap-server "${_IMPORT_PREFIX}/lib/libkdsoap-server.so.1.9.1" )

# Import target "KDSoap::kdwsdl2cpp" for configuration "Debug"
set_property(TARGET KDSoap::kdwsdl2cpp APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(KDSoap::kdwsdl2cpp PROPERTIES
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/bin/kdwsdl2cpp"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDSoap::kdwsdl2cpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDSoap::kdwsdl2cpp "${_IMPORT_PREFIX}/bin/kdwsdl2cpp" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
